@@ -5,17 +5,21 @@ use Exporter;
 use Test::More;
 use FileHandle;
 use File::Spec::Functions qw( :ALL );
+use File::Temp;
+use File::Slurp;
 
 use vars qw( @EXPORT @ISA );
 use Mail::Mbox::MessageParser;
 
 @ISA = qw( Exporter );
-@EXPORT = qw( Do_Diff Module_Installed %PROGRAMS
+@EXPORT = qw( Do_Diff Module_Installed %PROGRAMS $TEMPDIR
   Broken_Pipe No_such_file_or_directory $single_quote $command_separator
   $set_env
 );
 
-use vars qw( %PROGRAMS $single_quote $command_separator $set_env );
+use vars qw( $TEMPDIR %PROGRAMS $single_quote $command_separator $set_env );
+
+$TEMPDIR = File::Temp::tempdir();
 
 if ($^O eq 'MSWin32')
 {
@@ -48,19 +52,8 @@ sub Do_Diff
 
   local $Test::Builder::Level = 2;
 
-  my (@data1,@data2);
-
-  {
-    open IN, $filename;
-    @data1 = <IN>;
-    close IN;
-  }
-
-  {
-    open IN, $output_filename;
-    @data2 = <IN>;
-    close IN;
-  }
+  my @data1 = read_file($filename);
+  my @data2 = read_file($output_filename);
 
   is_deeply(\@data1,\@data2,"$filename compared to $output_filename");
 }
@@ -108,13 +101,10 @@ sub No_such_file_or_directory
 # doing this?
 sub Broken_Pipe
 {
-  mkdir catdir('t','temp'), 0700;
-
-  my $script_path = catfile('t','temp','broken_pipe.pl');
+  my $script_path = catfile($TEMPDIR,'broken_pipe.pl');
   my $dev_null = devnull();
 
-  open F, ">$script_path";
-  print F<<EOF;
+  write_file($script_path, <<EOF);
 unless (open B, '-|')
 {
   open(F, "|$^X -pe 'print' 2>$dev_null");
@@ -123,7 +113,6 @@ unless (open B, '-|')
   exit;
 }
 EOF
-  close F;
 
   my $result = `$^X $script_path 2>&1 1>$dev_null`;
 
